@@ -179,6 +179,7 @@ class VirtualEnv(Python, ABC):
             platform=interpreter.platform,
             extra={"executable": Path(interpreter.system_executable).resolve()},
             free_threaded=interpreter.free_threaded,
+            machine=getattr(interpreter, "machine", None),
         )
 
     def prepend_env_var_path(self) -> list[Path]:
@@ -234,8 +235,9 @@ class VirtualEnv(Python, ABC):
 
         """
         info = cls.get_virtualenv_py_info(path)
+        machine_suffix = f"-{m}" if (m := getattr(info, "machine", None)) else ""
         return PythonSpec.from_string_spec(
-            f"{info.implementation}{info.version_info.major}{info.version_info.minor}-{info.architecture}"
+            f"{info.implementation}{info.version_info.major}{info.version_info.minor}-{info.architecture}{machine_suffix}"
         )
 
     @staticmethod
