@@ -391,9 +391,14 @@ def test_cross_section_envpython_resolves_to_calling_env(tox_project: ToxProject
 
 def test_factor_conditional_falls_back_to_default(tox_project: ToxProjectCreator) -> None:
     py_ver = f"{sys.version_info[0]}.{sys.version_info[1]}"
-    ini = (
-        f"[tox]\nenv_list=py{py_ver}-a,py{py_ver}-b\nno_package=true\n[testenv]\nbase_python =\n    a: python{py_ver}\n"
-    )
+    ini = f"""\
+    [tox]
+    env_list=py{py_ver}-a,py{py_ver}-b
+    no_package=true
+    [testenv]
+    base_python =
+        a: python{py_ver}
+    """
     outcome = tox_project({"tox.ini": ini}).run("c", "-e", f"py{py_ver}-a,py{py_ver}-b", "-k", "base_python")
     outcome.assert_success()
     parser = ConfigParser(interpolation=None)
@@ -402,6 +407,32 @@ def test_factor_conditional_falls_back_to_default(tox_project: ToxProjectCreator
     assert parser.get(f"testenv:py{py_ver}-b", "base_python") == f"py{py_ver}"
 
 
+def test_cross_section_factor_conditional_resolves_to_empty(tox_project: ToxProjectCreator) -> None:
+    """Cross-section substitution resolves to empty when no factors match.
+
+    Regression test for gh-3809: {[section]key} where key contains factor-conditional values should resolve to empty
+    string when no factors match, not remain unresolved.
+
+    """
+    ini = """
+    [tox]
+    env_list=py39{,-keyfs_sqlite,-hash_hl}
+    no_package=true
+    [devpisettings]
+    storagebackend=
+        keyfs_sqlite: --backend-sqlite
+    [testenv]
+    commands=echo {[devpisettings]storagebackend}
+    allowlist_externals = echo
+    """
+    outcome = tox_project({"tox.ini": ini}).run("c", "-e", "py39,py39-keyfs_sqlite", "-k", "commands")
+    outcome.assert_success()
+    parser = ConfigParser(interpolation=None)
+    parser.read_string(outcome.out)
+    assert parser.get("testenv:py39", "commands") == "echo"
+    assert parser.get("testenv:py39-keyfs_sqlite", "commands") == "echo --backend-sqlite"
+
+
 def test_core_on_platform(tox_project: ToxProjectCreator) -> None:
     project = tox_project({"tox.ini": "[tox]\nno_package = true"})
     result = project.run("c", "-e", "py", "--core", "-k", "on_platform")
